@@ -1,4 +1,5 @@
 import os
+from typing import List
 from django.apps import apps as django_apps
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
@@ -43,7 +44,7 @@ class DjangoNatsNkeySettings:
 
     @property
     def NATS_SERVER_URI(self) -> str:
-        return getattr(settings, "NATS_SERVER_URI", "nats://nats:4222")
+        return getattr(settings, "NATS_SERVER_URI", "nats://nats:4223")
 
     @property
     def NATS_NKEYS_OPERATOR_NAME(self) -> str:
@@ -112,7 +113,7 @@ class DjangoNatsNkeySettings:
             "django_nats_nkeys.NatsOrganizationOwner",
         )
 
-    def get_NATS_ORGANIZATION_OWNER_MODEL(self) -> Model:
+    def get_nats_organization_owner_model(self) -> Model:
         model_name = self.get_nats_organization_owner_model_string()
         try:
             nats_app_model = django_apps.get_model(model_name)
@@ -229,5 +230,34 @@ class DjangoNatsNkeySettings:
             )
         return nats_user_model
 
+    def get_nats_app_models_string(self) -> str:
+        pass
+
+    def get_nats_app_models(self) -> List[Model]:
+        model_strings = getattr(
+            settings,
+            "NATS_APP_MODELS",
+            [
+                self.get_nats_organization_app_model_string(),
+                self.get_nats_robot_app_model_string(),
+            ],
+        )
+        app_models: List[Model] = []
+
+        for model_name in model_strings:
+            try:
+                model = django_apps.get_model(model_name)
+                app_models.append(model)
+            except ValueError:
+                raise ImproperlyConfigured(
+                    "NATS_APP_MODELS must be a list of models in the format: 'app_label.model_name'."
+                )
+            except LookupError:
+                raise ImproperlyConfigured(
+                    "NATS_APP_MODELS refers to model '{model}' "
+                    "that has not been installed.".format(model=model_name)
+                )
+        return app_models
+
 
 nats_nkeys_settings = DjangoNatsNkeySettings()
